@@ -142,3 +142,6 @@ DEFAULT_PROJECT_ACCESS = 'MEMBER_OWNER'
 
 # Default to not sending the Access-Control-Allow-Origin header on api/store
 ALLOW_ORIGIN = None
+
+# Enable capturing of JavaScript errors (Sentry internal errors)
+USE_JS_CLIENT = False
